# app

## Purpose
Composition root for the public `Vyro` application object.

## Owns
- `Vyro` class entrypoint and app wiring bootstrap.

## Entry Points
- `vyro.app.vyro.Vyro`

## Not Here
- Runtime feature implementations.
